/*
 * DemosceneMusic - Core.java - Copyright © 2012 David Roden
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */

package net.pterodactylus.demoscenemusic.core;

import javax.naming.Context;
import javax.naming.InitialContext;
import javax.naming.NamingException;
import javax.servlet.ServletContextEvent;
import javax.servlet.ServletContextListener;
import javax.sql.DataSource;

import net.pterodactylus.demoscenemusic.data.DataManager;
import net.pterodactylus.util.database.AbstractDatabase;
import net.pterodactylus.util.database.Database;

import org.openid4java.consumer.ConsumerManager;

/**
 * TODO
 *
 * @author <a href="mailto:bombe@pterodactylus.net">David ‘Bombe’ Roden</a>
 */
public class Core implements ServletContextListener {

	private DataManager dataManager;

	/** The data directory. */
	private DataDirectory dataDirectory;

	private final ConsumerManager consumerManager = new ConsumerManager();

	public DataManager getDataManager() {
		return dataManager;
	}

	/**
	 * @return the consumerManager
	 */
	public ConsumerManager getConsumerManager() {
		return consumerManager;
	}

	/**
	 * Returns the data directory helper.
	 *
	 * @return The data directory
	 */
	public DataDirectory getDataDirectory() {
		return dataDirectory;
	}

	//
	// SERVLETCONTEXTLISTENER METHODS
	//

	/**
	 * {@inheritDoc}
	 */
	@Override
	public void contextInitialized(ServletContextEvent servletContextEvent) {
		servletContextEvent.getServletContext().setAttribute("core", this);
		dataDirectory = new DataDirectory(servletContextEvent.getServletContext().getInitParameter("data-directory"));
		try {
			Context context = new InitialContext();
			DataSource dataSource = (DataSource) context.lookup("java:/comp/env/jdbc/demosceneMusic");
			Database database = AbstractDatabase.fromDataSource(dataSource);
			dataManager = new DataManager(database);
			servletContextEvent.getServletContext().setAttribute("dataManager", dataManager);
		} catch (NamingException ne1) {
			servletContextEvent.getServletContext().log("Could not create database connection.", ne1);
		}
	}

	/**
	 * {@inheritDoc}
	 */
	@Override
	public void contextDestroyed(ServletContextEvent arg0) {
		/* do nothing. */
	}

}
